package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.Feedback;

import java.util.List;

/**
 * 问题反馈Mapper接口
 * 
 * @author ruoyi
 * @date 2022-10-21
 */
public interface FeedbackMapper 
{
    /**
     * 查询问题反馈
     * 
     * @param feedbackId 问题反馈ID
     * @return 问题反馈
     */
    public Feedback selectFeedbackById(Long feedbackId);

    /**
     * 查询问题反馈列表
     * 
     * @param feedback 问题反馈
     * @return 问题反馈集合
     */
    public List<Feedback> selectFeedbackList(Feedback feedback);

    /**
     * 新增问题反馈
     * 
     * @param feedback 问题反馈
     * @return 结果
     */
    public int insertFeedback(Feedback feedback);

    /**
     * 修改问题反馈
     * 
     * @param feedback 问题反馈
     * @return 结果
     */
    public int updateFeedback(Feedback feedback);

    /**
     * 删除问题反馈
     * 
     * @param feedbackId 问题反馈ID
     * @return 结果
     */
    public int deleteFeedbackById(Long feedbackId);

    /**
     * 批量删除问题反馈
     * 
     * @param feedbackIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteFeedbackByIds(String[] feedbackIds);

}


